import os

broker_url = "pyamqp://guest@{hostname}:5672//".format(
    hostname=os.getenv("DAGSTER_CELERY_BROKER_HOST", "localhost")
)

backend = "rpc://"

result_backend = backend

task_default_priority = 5

task_default_queue = "dagster"

worker_prefetch_multiplier = 4

broker_transport_options = {
    # these defaults were lifted from examples - worth updating after some experience
    "max_retries": 3,
    "interval_start": 0,
    "interval_step": 0.2,
    "interval_max": 0.5,
}



from pathlib import Path
from typing import Dict

from setuptools import find_packages, setup


def get_version() -> str:
    version: Dict[str, str] = {}
    with open(Path(__file__).parent / "dagster_celery/version.py", encoding="utf8") as fp:
        exec(fp.read(), version)  # pylint: disable=W0122

    return version["__version__"]


ver = get_version()
# dont pin dev installs to avoid pip dep resolver issues
pin = "" if ver == "0+dev" else f"=={ver}"
setup(
    name="dagster-celery",
    version=ver,
    author="Elementl",
    author_email="hello@elementl.com",
    license="Apache-2.0",
    description="Package for using Celery as Dagster's execution engine.",
    url="https://github.com/dagster-io/dagster/tree/master/python_modules/libraries/dagster-celery",
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    packages=find_packages(exclude=["dagster_celery_tests*"]),
    entry_points={"console_scripts": ["dagster-celery = dagster_celery.cli:main"]},
    install_requires=[
        "dagster==1.1.4",
        "celery>=4.3.0",
        "click>=5.0,<9.0",
        "importlib_metadata<5.0.0; python_version<'3.8'",  # https://github.com/celery/celery/issues/7783
    ],
    extras_require={
        "flower": ["flower"],
        "redis": ["redis"],
        "kubernetes": ["kubernetes"],
        "test": ["docker"],
    },
    zip_safe=False,
)
